# This file contains a list of CVE's where resolution has proven to be impractical
# or there is no reasonable action the Yocto Project can take to resolve the issue.
# It contains all the information we are aware of about an issue and analysis about
# why we believe it can't be fixed/handled. Additional information is welcome through
# patches to the file.
#
# Include this file in your local.conf or distro.conf to exclude these CVE's
# from the cve-check results or add to the bitbake command with:
#     -R conf/distro/include/cve-extra-exclusions.inc
#
# The file is not included by default since users should review this data to ensure
# it matches their expectations and usage of the project.
#
# We may also include "in-flight" information about current/ongoing CVE work with
# the aim of sharing that work and ensuring we don't duplicate it.
#


# strace https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2000-0006
# CVE is more than 20 years old with no resolution evident
# broken links in CVE database references make resolution impractical
CVE_CHECK_IGNORE += "CVE-2000-0006"

# epiphany https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2005-0238
# The issue here is spoofing of domain names using characters from other character sets.
# There has been much discussion amongst the epiphany and webkit developers and
# whilst there are improvements about how domains are handled and displayed to the user
# there is unlikely ever to be a single fix to webkit or epiphany which addresses this
# problem. Ignore this CVE as there isn't any mitigation or fix or way to progress this further
# we can seem to take.
CVE_CHECK_IGNORE += "CVE-2005-0238"

# glibc https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2010-4756
# Issue is memory exhaustion via glob() calls, e.g. from within an ftp server
# Best discussion in https://bugzilla.redhat.com/show_bug.cgi?id=681681
# Upstream don't see it as a security issue, ftp servers shouldn't be passing
# this to libc glob. Exclude as upstream have no plans to add BSD's GLOB_LIMIT or similar
CVE_CHECK_IGNORE += "CVE-2010-4756"

# go https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2020-29509
# go https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2020-29511
# The encoding/xml package in go can potentially be used for security exploits if not used correctly
# CVE applies to a netapp product as well as flagging a general issue. We don't ship anything
# exposing this interface in an exploitable way
CVE_CHECK_IGNORE += "CVE-2020-29509 CVE-2020-29511"

# db
# Since Oracle relicensed bdb, the open source community is slowly but surely replacing bdb with
# supported and open source friendly alternatives. As a result these CVEs are unlikely to ever be fixed.
CVE_CHECK_IGNORE += "CVE-2015-2583 CVE-2015-2624 CVE-2015-2626 CVE-2015-2640 CVE-2015-2654 \
CVE-2015-2656 CVE-2015-4754 CVE-2015-4764 CVE-2015-4774 CVE-2015-4775 CVE-2015-4776 CVE-2015-4777 \
CVE-2015-4778 CVE-2015-4779 CVE-2015-4780 CVE-2015-4781 CVE-2015-4782 CVE-2015-4783 CVE-2015-4784 \
CVE-2015-4785 CVE-2015-4786 CVE-2015-4787 CVE-2015-4788 CVE-2015-4789 CVE-2015-4790 CVE-2016-0682 \
CVE-2016-0689 CVE-2016-0692 CVE-2016-0694 CVE-2016-3418 CVE-2020-2981"


#
# Kernel CVEs, e.g. linux-yocto*
#
# For OE-Core our policy is to stay as close to the kernel stable releases as we can. This should
# ensure the bulk of the major kernel CVEs are fixed and we don't dive into each individual issue
# as the stable maintainers are much more able to do that.
#
# Rather than just ignore all kernel CVEs, list the ones we ignore on this basis here, allowing new
# issues to be visible. If anyone wishes to clean up CPE entries with NIST for these, we'd
# welcome than and then entries can likely be removed from here.
#
# 1999-2010
CVE_CHECK_IGNORE += "CVE-1999-0524 CVE-1999-0656 CVE-2006-2932 CVE-2007-2764 CVE-2007-4998 CVE-2008-2544 \
                     CVE-2008-4609 CVE-2010-0298 CVE-2010-4563"
# 2011-2017
CVE_CHECK_IGNORE += "CVE-2011-0640 CVE-2014-2648 CVE-2014-8171 CVE-2016-0774 CVE-2016-3695 CVE-2016-3699 \
                     CVE-2017-1000255 CVE-2017-1000377 CVE-2017-5897 CVE-2017-6264"
# 2018
CVE_CHECK_IGNORE += "CVE-2018-1000026 CVE-2018-10840 CVE-2018-10876 CVE-2018-10882 CVE-2018-10901 CVE-2018-10902 \
                     CVE-2018-14625 CVE-2018-16880 CVE-2018-16884 CVE-2018-5873 CVE-2018-6559"
# 2019
CVE_CHECK_IGNORE += "CVE-2019-10126 CVE-2019-14899 CVE-2019-18910 CVE-2019-3016 CVE-2019-3819 CVE-2019-3846 CVE-2019-3887"
# 2020
CVE_CHECK_IGNORE += "CVE-2020-10732 CVE-2020-10742 CVE-2020-16119 CVE-2020-1749 CVE-2020-25672 CVE-2020-27820 CVE-2020-35501 CVE-2020-8834"

# https://nvd.nist.gov/vuln/detail/CVE-2020-27784
# Introduced in version v4.1 b26394bd567e5ebe57ec4dee7fe6cd14023c96e9
# Patched in kernel since v5.10	e8d5f92b8d30bb4ade76494490c3c065e12411b1
# Backported in version v5.4.73	e9e791f5c39ab30e374a3b1a9c25ca7ff24988f3
CVE_CHECK_IGNORE += "CVE-2020-27784"

# 2021
CVE_CHECK_IGNORE += "CVE-2021-20194 CVE-2021-20226 CVE-2021-20265 CVE-2021-3564 CVE-2021-3743 CVE-2021-3847 CVE-2021-4002 \
                     CVE-2021-4090 CVE-2021-4095 CVE-2021-4197 CVE-2021-4202 CVE-2021-44879 CVE-2021-45402"

# https://nvd.nist.gov/vuln/detail/CVE-2021-3669
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.15 20401d1058f3f841f35a594ac2fc1293710e55b9
CVE_CHECK_IGNORE += "CVE-2021-3669"

# https://nvd.nist.gov/vuln/detail/CVE-2021-3759
# Introduced in version v4.5 a9bb7e620efdfd29b6d1c238041173e411670996
# Patched in kernel since v5.15 18319498fdd4cdf8c1c2c48cd432863b1f915d6f
# Backported in version v5.4.224 bad83d55134e647a739ebef2082541963f2cbc92
# Backported in version v5.10.154 836686e1a01d7e2fda6a5a18252243ff30a6e196
CVE_CHECK_IGNORE += "CVE-2021-3759"

# https://nvd.nist.gov/vuln/detail/CVE-2021-4218
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.8 32927393dc1ccd60fb2bdc05b9e8e88753761469
CVE_CHECK_IGNORE += "CVE-2021-4218"

# 2022
CVE_CHECK_IGNORE += "CVE-2022-0185 CVE-2022-0264 CVE-2022-0286 CVE-2022-0330 CVE-2022-0382 CVE-2022-0433 CVE-2022-0435 \
                     CVE-2022-0492 CVE-2022-0494 CVE-2022-0500 CVE-2022-0516 CVE-2022-0617 CVE-2022-0742 CVE-2022-0854 \
                     CVE-2022-0995 CVE-2022-0998 CVE-2022-1011 CVE-2022-1015 CVE-2022-1048 CVE-2022-1055 CVE-2022-1195 \
                     CVE-2022-1353 CVE-2022-24122 CVE-2022-24448 CVE-2022-24958 CVE-2022-24959 CVE-2022-25258 CVE-2022-25265 \
                     CVE-2022-25375 CVE-2022-26490 CVE-2022-26878 CVE-2022-26966 CVE-2022-27223 CVE-2022-27666 CVE-2022-27950 \
                     CVE-2022-28356 CVE-2022-28388 CVE-2022-28389 CVE-2022-28390 CVE-2022-28796 CVE-2022-28893 CVE-2022-29156 \
                     CVE-2022-29582 CVE-2022-29968"

# https://nvd.nist.gov/vuln/detail/CVE-2022-0480
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.15 0f12156dff2862ac54235fc72703f18770769042
CVE_CHECK_IGNORE += "CVE-2022-0480"

# https://nvd.nist.gov/vuln/detail/CVE-2022-1184
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.19 46c116b920ebec58031f0a78c5ea9599b0d2a371
# Backported in version v5.4.198 17034d45ec443fb0e3c0e7297f9cd10f70446064
# Backported in version v5.10.121 da2f05919238c7bdc6e28c79539f55c8355408bb
# Backported in version v5.15.46 ca17db384762be0ec38373a12460081d22a8b42d
CVE_CHECK_IGNORE += "CVE-2022-1184"

# https://nvd.nist.gov/vuln/detail/CVE-2022-1462
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.19 a501ab75e7624d133a5a3c7ec010687c8b961d23
# Backported in version v5.4.208 f7785092cb7f022f59ebdaa181651f7c877df132
# Backported in version v5.10.134 08afa87f58d83dfe040572ed591b47e8cb9e225c
# Backported in version v5.15.58 b2d1e4cd558cffec6bfe318f5d74e6cffc374d29
CVE_CHECK_IGNORE += "CVE-2022-1462"

# https://nvd.nist.gov/vuln/detail/CVE-2022-2308
# Introduced in version v5.15 c8a6153b6c59d95c0e091f053f6f180952ade91e
# Patched in kernel since v6.0 46f8a29272e51b6df7393d58fc5cb8967397ef2b
# Backported in version v5.15.72 dc248ddf41eab4566e95b1ee2433c8a5134ad94a
# Backported in version v5.19.14 38d854c4a11c3bbf6a96ea46f14b282670c784ac
CVE_CHECK_IGNORE += "CVE-2022-2308"

# https://nvd.nist.gov/vuln/detail/CVE-2022-2327
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.10.125 df3f3bb5059d20ef094d6b2f0256c4bf4127a859
CVE_CHECK_IGNORE += "CVE-2022-2327"

# https://nvd.nist.gov/vuln/detail/CVE-2022-2663
# Introduced in version v2.6.20 869f37d8e48f3911eb70f38a994feaa8f8380008
# Patched in kernel since v6.0 0efe125cfb99e6773a7434f3463f7c2fa28f3a43
# Backported in version v5.4.213 36f7b71f8ad8e4d224b45f7d6ecfeff63b091547
# Backported in version v5.10.143 e12ce30fe593dd438c5b392290ad7316befc11ca
# Backported in version v5.15.68 451c9ce1e2fc9b9e40303bef8e5a0dca1a923cc4
# Backported in version v5.19.9 6cf0609154b2ce8d3ae160e7506ab316400a8d3d
CVE_CHECK_IGNORE += "CVE-2022-2663"

# https://nvd.nist.gov/vuln/detail/CVE-2022-2785
# Introduced in version v5.18 b1d18a7574d0df5eb4117c14742baf8bc2b9bb74
# Patched in kernel since v6.0 86f44fcec22ce2979507742bc53db8400e454f46
# Backported in version v5.19.4 b429d0b9a7a0f3dddb1f782b72629e6353f292fd
CVE_CHECK_IGNORE += "CVE-2022-2785"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3176
# Introduced in version v5.1 221c5eb2338232f7340386de1c43decc32682e58
# Patched in kernel since v5.17 791f3465c4afde02d7f16cf7424ca87070b69396
# Backported in version v5.15.65 e9d7ca0c4640cbebe6840ee3bac66a25a9bacaf5
CVE_CHECK_IGNORE += "CVE-2022-3176"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3526
# Introduced in version v5.13 427f0c8c194b22edcafef1b0a42995ddc5c2227d
# Patched in kernel since v5.18 e16b859872b87650bb55b12cca5a5fcdc49c1442
# Backported in version v5.15.35 8f79ce226ad2e9b2ec598de2b9560863b7549d1b
CVE_CHECK_IGNORE += "CVE-2022-3526"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3621
# Introduced in version v2.60.30 05fe58fdc10df9ebea04c0eaed57adc47af5c184
# Patched in kernel since v6.1 21a87d88c2253350e115029f14fe2a10a7e6c856
# Backported in version v5.4.218 792211333ad77fcea50a44bb7f695783159fc63c
# Backported in version v5.10.148 3f840480e31495ce674db4a69912882b5ac083f2
# Backported in version v5.15.74 1e512c65b4adcdbdf7aead052f2162b079cc7f55
# Backported in version v5.19.16 caf2c6b580433b3d3e413a3d54b8414a94725dcd
CVE_CHECK_IGNORE += "CVE-2022-3621"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3623
# Introduced in version v5.1 5480280d3f2d11d47f9be59d49b20a8d7d1b33e8
# Patched in kernel since v6.1 fac35ba763ed07ba93154c95ffc0c4a55023707f
# Backported in version v5.4.228 176ba4c19d1bb153aa6baaa61d586e785b7d736c
# Backported in version v5.10.159 fccee93eb20d72f5390432ecea7f8c16af88c850
# Backported in version v5.15.78 3a44ae4afaa5318baed3c6e2959f24454e0ae4ff
# Backported in version v5.19.17 86a913d55c89dd13ba070a87f61a493563e94b54
CVE_CHECK_IGNORE += "CVE-2022-3623"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3624
# Introduced in version v6.0 d5410ac7b0baeca91cf73ff5241d35998ecc8c9e
# Patched in kernel since v6.0 4f5d33f4f798b1c6d92b613f0087f639d9836971
CVE_CHECK_IGNORE += "CVE-2022-3624"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3625
# Introduced in version v4.19 45f05def5c44c806f094709f1c9b03dcecdd54f0
# Patched in kernel since v6.0 6b4db2e528f650c7fb712961aac36455468d5902
# Backported in version v5.4.211 1ad4ba9341f15412cf86dc6addbb73871a10212f
# Backported in version v5.10.138 0e28678a770df7989108327cfe86f835d8760c33
# Backported in version v5.15.63 c4d09fd1e18bac11c2f7cf736048112568687301
# Backported in version v5.19.4 26bef5616255066268c0e40e1da10cc9b78b82e9
CVE_CHECK_IGNORE += "CVE-2022-3625"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3629
# Introduced in version v3.9 d021c344051af91f42c5ba9fdedc176740cbd238
# Patched in kernel since v6.0 7e97cfed9929eaabc41829c395eb0d1350fccb9d
# Backported in version v5.4.211 f82f1e2042b397277cd39f16349950f5abade58d
# Backported in version v5.10.138 38ddccbda5e8b762c8ee06670bb1f64f1be5ee50
# Backported in version v5.15.63 e4c0428f8a6fc8c218d7fd72bddd163f05b29795
# Backported in version v5.19.4 8ff5db3c1b3d6797eda5cd326dcd31b9cd1c5f72
CVE_CHECK_IGNORE += "CVE-2022-3629"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3630
# Introduced in version v5.19 85e4ea1049c70fb99de5c6057e835d151fb647da
# Patched in kernel since v6.0 fb24771faf72a2fd62b3b6287af3c610c3ec9cf1
# Backported in version v5.19.4 7a369dc87b66acc85d0cffcf39984344a203e20b
CVE_CHECK_IGNORE += "CVE-2022-3630"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3633
# Introduced in version v5.4 9d71dd0c70099914fcd063135da3c580865e924c
# Patched in kernel since v6.0 8c21c54a53ab21842f5050fa090f26b03c0313d6
# Backported in version v5.4.211 04e41b6bacf474f5431491f92e981096e8cc8e93
# Backported in version v5.10.138 a220ff343396bae8d3b6abee72ab51f1f34b3027
# Backported in version v5.15.63 98dc8fb08299ab49e0b9c08daedadd2f4de1a2f2
# Backported in version v5.19.4 a0278dbeaaf7ca60346c62a9add65ae7d62564de
CVE_CHECK_IGNORE += "CVE-2022-3633"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3635
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v6.0 3f4093e2bf4673f218c0bf17d8362337c400e77b
# Backported in version v5.4.211 9a6cbaa50f263b12df18a051b37f3f42f9fb5253
# Backported in version v5.10.138 a0ae122e9aeccbff75014c4d36d11a9d32e7fb5e
# Backported in version v5.15.63 a5d7ce086fe942c5ab422fd2c034968a152be4c4
# Backported in version v5.19.4 af412b252550f9ac36d9add7b013c2a2c3463835
CVE_CHECK_IGNORE += "CVE-2022-3635"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3636
# Introduced in version v5.19 33fc42de33278b2b3ec6f3390512987bc29a62b7
# Patched in kernel since v5.19 17a5f6a78dc7b8db385de346092d7d9f9dc24df6
# The vulnerability has been introduced and patched in rc1 of v5.19.
CVE_CHECK_IGNORE += "CVE-2022-3636"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3646
# Introduced in version v2.6.30 9ff05123e3bfbb1d2b68ba1d9bf1f7d1dffc1453
# Patched in kernel since v6.1 d0d51a97063db4704a5ef6bc978dddab1636a306
# Backported in version v5.4.218 b7e409d11db9ce9f8bc05fcdfa24d143f60cd393
# Backported in version v5.10.148 aad4c997857f1d4b6c1e296c07e4729d3f8058ee
# Backported in version v5.15.74 44b1ee304bac03f1b879be5afe920e3a844e40fc
# Backported in version v5.19.16 4755fcd844240857b525f6e8d8b65ee140fe9570
CVE_CHECK_IGNORE += "CVE-2022-3646"

# https://nvd.nist.gov/vuln/detail/CVE-2022-3649
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v6.1 d325dc6eb763c10f591c239550b8c7e5466a5d09
# Backported in version v5.4.220 d1c2d820a2cd73867b7d352e89e92fb3ac29e926
# Backported in version v5.10.148 21ee3cffed8fbabb669435facfd576ba18ac8652
# Backported in version v5.15.74 cb602c2b654e26763226d8bd27a702f79cff4006
# Backported in version v5.19.16 394b2571e9a74ddaed55aa9c4d0f5772f81c21e4
CVE_CHECK_IGNORE += "CVE-2022-3649"

# https://nvd.nist.gov/vuln/detail/CVE-2022-26365
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.19 2f446ffe9d737e9a844b97887919c4fda18246e7
# Backported in version v5.4.204 42112e8f94617d83943f8f3b8de2b66041905506
# Backported in version v5.10.129 cfea428030be836d79a7690968232bb7fa4410f1
# Backported in version v5.15.53 7ed65a4ad8fa9f40bc3979b32c54243d6a684ec9
CVE_CHECK_IGNORE += "CVE-2022-26365"

# https://nvd.nist.gov/vuln/detail/CVE-2022-33740
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.19 307c8de2b02344805ebead3440d8feed28f2f010
# Backported in version v5.4.204 04945b5beb73019145ac17a2565526afa7293c14
# Backported in version v5.10.129 728d68bfe68d92eae1407b8a9edc7817d6227404
# Backported in version v5.15.53 5dd0993c36832d33820238fc8dc741ba801b7961
CVE_CHECK_IGNORE += "CVE-2022-33740"

# https://nvd.nist.gov/vuln/detail/CVE-2022-33741
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.19 4491001c2e0fa69efbb748c96ec96b100a5cdb7e
# Backported in version v5.4.204 ede57be88a5fff42cd00e6bcd071503194d398dd
# Backported in version v5.10.129 4923217af5742a796821272ee03f8d6de15c0cca
# Backported in version v5.15.53 ed3cfc690675d852c3416aedb271e0e7d179bf49
CVE_CHECK_IGNORE += "CVE-2022-33741"

# https://nvd.nist.gov/vuln/detail/CVE-2022-33742
# Introduced in version v2.6.12 1da177e4c3f41524e886b7f1b8a0c1fc7321cac2
# Patched in kernel since v5.19 2400617da7eebf9167d71a46122828bc479d64c9
# Backported in version v5.4.204 60ac50daad36ef3fe9d70d89cfe3b95d381db997
# Backported in version v5.10.129 cbbd2d2531539212ff090aecbea9877c996e6ce6
# Backported in version v5.15.53 6d0a9127279a4533815202e30ad1b3a39f560ba3
CVE_CHECK_IGNORE += "CVE-2022-33742"


# Wrong CPE in NVD database
# https://nvd.nist.gov/vuln/detail/CVE-2022-3563
# https://nvd.nist.gov/vuln/detail/CVE-2022-3637
# Those issue do not affect the kernel, patchs listed on CVE pages links to https://git.kernel.org/pub/scm/bluetooth/bluez.git
CVE_CHECK_IGNORE += "CVE-2022-3563 CVE-2022-3637"

# qemu:qemu-native:qemu-system-native https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2021-20255
# There was a proposed patch https://lists.gnu.org/archive/html/qemu-devel/2021-02/msg06098.html
# qemu maintainers say the patch is incorrect and should not be applied
# Ignore from OE's perspectivee as the issue is of low impact, at worst sitting in an infinite loop rather than exploitable
CVE_CHECK_IGNORE += "CVE-2021-20255"

# qemu:qemu-native:qemu-system-native https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2019-12067
# There was a proposed patch but rejected by upstream qemu. It is unclear if the issue can
# still be reproduced or where exactly any bug is.
# Ignore from OE's perspective as we'll pick up any fix when upstream accepts one.
CVE_CHECK_IGNORE += "CVE-2019-12067"

# nasm:nasm-native https://web.nvd.nist.gov/view/vuln/detail?vulnId=CVE-2020-18974
# It is a fuzzing related buffer overflow. It is of low impact since most devices
# wouldn't expose an assembler. The upstream is inactive and there is little to be
# done about the bug, ignore from an OE perspective.
CVE_CHECK_IGNORE += "CVE-2020-18974"



